@@ -1,35 +1,36 @@
 #! -*- encoding: utf-8 -*-
+import logging
 import os
 import sys
-import logging
+from typing import Optional
 
 import click
 from autoupgrade import Package
 
 from suite_py.__version__ import __version__
+from suite_py.commands.aggregator import Aggregator
 from suite_py.commands.ask_review import AskReview
+from suite_py.commands.bump import Bump
 from suite_py.commands.check import Check
 from suite_py.commands.create_branch import CreateBranch
-from suite_py.commands.release import Release
 from suite_py.commands.deploy import Deploy
 from suite_py.commands.generator import Generator
 from suite_py.commands.id import ID
 from suite_py.commands.ip import IP
+from suite_py.commands.login import Login
 from suite_py.commands.merge_pr import MergePR
 from suite_py.commands.open_pr import OpenPR
 from suite_py.commands.project_lock import ProjectLock
-from suite_py.commands.status import Status
-from suite_py.commands.aggregator import Aggregator
-from suite_py.commands.secret import Secret
-from suite_py.commands.login import Login
 from suite_py.commands.qa import QA
+from suite_py.commands.release import Release
+from suite_py.commands.secret import Secret
+from suite_py.commands.status import Status
+from suite_py.lib import logger
 from suite_py.lib.config import Config
 from suite_py.lib.handler import git_handler as git
 from suite_py.lib.handler import prompt_utils
 from suite_py.lib.tokens import Tokens
 
-from suite_py.lib import logger
-
 ALLOW_NO_GIT_SUBCOMMAND = ["login", "qa", "aggregator"]
 ALLOW_NO_HOME_SUBCOMMAND = ["login", "qa", "aggregator"]
 
@@ -100,6 +101,13 @@ def main(ctx, project, timeout, verbose):
         os.chdir(os.path.join(config.user["projects_home"], ctx.obj["project"]))
 
 
+@main.command("bump", help="Bumps the project version based on the .versions.yml file")
+@click.option("--project", required=False, type=str)
+@click.pass_obj
+def bump(obj, project: Optional[str] = None):
+    Bump(obj["project"], obj["config"], obj["tokens"]).run(project=project)
+
+
 @main.command(
     "create-branch", help="Create local branch and set the YouTrack card in progress"
 )
