@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
-import sys
 import re
-import semver
+import sys
 
+import semver
 from halo import Halo
 
 from suite_py.lib import logger
@@ -12,6 +12,7 @@ from suite_py.lib.handler.captainhook_handler import CaptainHook
 from suite_py.lib.handler.drone_handler import DroneHandler
 from suite_py.lib.handler.git_handler import GitHandler
 from suite_py.lib.handler.github_handler import GithubHandler
+from suite_py.lib.handler.version_handler import DEFAULT_VERSION, VersionHandler
 from suite_py.lib.handler.youtrack_handler import YoutrackHandler
 
 
@@ -30,6 +31,7 @@ class Release:
         self._git = GitHandler(project, config)
         self._drone = DroneHandler(config, tokens, repo=project)
         self._countries = _parse_available_countries(self._drone)
+        self._version = VersionHandler(self._repo, self._git, self._github)
 
     def run(self):
         self._stop_if_prod_locked()
@@ -48,13 +50,6 @@ class Release:
         else:
             self._rollback()
 
-    def _get_latest(self):
-        tags = self._repo.get_tags()
-        tag = git.get_last_tag_number(tags)
-        latest_release = self._get_release(tag)
-
-        return latest_release.tag_name if latest_release else tag
-
     def _stop_if_prod_locked(self):
         request = self._captainhook.status(self._project, "production")
         if request.status_code != 200:
@@ -76,10 +71,9 @@ class Release:
         return None
 
     def _create(self):
-        latest = self._get_latest()
-        if latest:
+        latest = self._version.get_latest_version()
+        if latest != DEFAULT_VERSION:
             logger.info(f"The current release is {latest}")
-            versions = _bump_versions(latest)
             commits = self._github.get_commits_since_release(self._repo, latest)
 
             _check_migrations_deploy(commits)
@@ -93,23 +87,18 @@ class Release:
             if not prompt_utils.ask_confirm("Do you want to continue?"):
                 sys.exit()
 
-            new_version = prompt_utils.ask_choices(
-                "Select version:",
-                [
-                    {"name": f"Patch {versions['patch']}", "value": versions["patch"]},
-                    {"name": f"Minor {versions['minor']}", "value": versions["minor"]},
-                    {"name": f"Major {versions['major']}", "value": versions["major"]},
-                ],
-            )
+            new_version = self._version.select_new_version(latest)
 
         else:
             # Se non viene trovata la release e non ci sono tag, viene saltato il check delle migrations e l'update delle card su youtrack
-            logger.warning("No tags found, I'm about to push the tag 0.1.0")
+            logger.warning(
+                f"No tags found, I'm about to push the tag {DEFAULT_VERSION}"
+            )
             if not prompt_utils.ask_confirm(
                 "Are you sure you want to continue?", default=False
             ):
                 sys.exit()
-            new_version = "0.1.0"
+            new_version = DEFAULT_VERSION
             message = f"First release with tag {new_version}"
 
         self._create_release(new_version, message)
@@ -372,14 +361,6 @@ class Release:
         return False
 
 
-def _bump_versions(current):
-    return {
-        "patch": semver.bump_patch(current),
-        "minor": semver.bump_minor(current),
-        "major": semver.bump_major(current),
-    }
-
-
 def _check_migrations_deploy(commits):
     if not commits:
         logger.error("ERROR: no commit found")
